<?php
/*
	@! MADISS
	@@ MAke DIgital Signage Simple
	@@ Version 1.2 (11/2015)
-----------------------------------------------------------------------------	
	** author: Benoît FACCHINETTI 
	** Site: http://benserveur.fr.cr/MADISS
	** email: benoitfacchinetti@gmail.com
-----------------------------------------------------------------------------
	@@package: Functions
	@@version: 1.2
*/
if(!defined('IN_MADISS')) die('Action impossible ! (erreur: Script could not be opened alone)'); //Vérifi si appeler par nos scripts

function _SECURISE($string)
{
	$string = htmlspecialchars(htmlentities($string));
	
	return $string;
}

function _UPDATECONFIG($name, $value)
{ 
	global $pdo;
	try {
			$q = "UPDATE 'config' SET `value` = :value WHERE `name` = :name";
			$check_query = $pdo->prepare($q);
			$check_query->bindParam(':name', $name, PDO::PARAM_STR);
			$check_query->bindParam(':value', $value, PDO::PARAM_STR);
			$check_query->execute();
		} catch(PDOException $e) {
			return false;
		}
		return true;
}

function _GETCONFIG($name)
{ 
	global $pdo;
	try {
			$q = "SELECT * FROM 'config' WHERE `name` = :name";
			$check_query = $pdo->prepare($q);
			$check_query->bindParam(':name', $name, PDO::PARAM_STR);
			$check_query->setFetchMode(PDO::FETCH_ASSOC);
			$check_query->execute();
		} catch(PDOException $e) {
			// echo $e;
		}
		$out = $check_query->fetch();
	return $out;
}

function _GETMODULESINFOS($module_name)
{ 
	global $pdo;
	
	try {
			$q = "SELECT * FROM 'modules' WHERE `module_name` = :name";
			$check_module = $pdo->prepare($q);
			$check_module->bindParam(':name', $module_name, PDO::PARAM_STR);
			$check_module->setFetchMode(PDO::FETCH_ASSOC);
			$check_module->execute();
		} catch(PDOException $e) {
			// echo $e;
		}
		$out_module = $check_module->fetch();
	return $out_module;
}

function _UPDATEMODULEINFOS($module_name, $value)
{ 
	global $pdo;
	try {
			$q = "UPDATE 'modules' SET `module_param` = :value WHERE `module_name` = :name";
			$check_query = $pdo->prepare($q);
			$check_query->bindParam(':name', $module_name, PDO::PARAM_STR);
			$check_query->bindParam(':value', $value, PDO::PARAM_STR);
			$check_query->execute();
		} catch(PDOException $e) {
			return false;
		}
		return true;
}

function getFolderSize($path){
	$size = 0;
	foreach(new RecursiveIteratorIterator(new RecursiveDirectoryIterator($path)) as $file){
		$size += $file->getSize();
	}
 
	
	$size = round($size/(1024*1024),2);
 
	return $size;
}

function spaceAvailable($path){
	
	$allowed_space = _GETCONFIG('allowed_space')['value'];
	$space_used = getFolderSize($path);
	if($space_used < $allowed_space){
		return true;
	}else{
		return false;
	}
}

function XMLReader($url){

	if(is_object($flux = simplexml_load_file($url)))
	{
	   $donnee = $flux->channel;

	   //Lecture des données

	   return $donnee;
	   
	}else return false;
}

function get_browser_name($user_agent)
{
    if (strpos($user_agent, 'Opera') || strpos($user_agent, 'OPR/')){ return 'Opera';}
    elseif (strpos($user_agent, 'Edge')){ return 'Edge';}
    elseif (strpos($user_agent, 'Chrome')){ return 'Chrome';}
    elseif (strpos($user_agent, 'Safari')){ return 'Safari';}
    elseif (strpos($user_agent, 'Firefox')){ return 'Firefox';}
    elseif (strpos($user_agent, 'MSIE') || strpos($user_agent, 'Trident/7')){ return 'Internet Explorer';}
    
    return 'Other';
}

function get_client_ip() {
	//Retourne la vraie adresse IP du client
        return (isset($_SERVER['HTTP_X_FORWARDED_FOR'])) ? $_SERVER['HTTP_X_FORWARDED_FOR'] : $_SERVER['REMOTE_ADDR'];
}

function get_serveur_ip() {
	//Retourne la vraie adresse IP du serveur
        return $_SERVER['SERVER_ADDR'];
}

function MDPCrypt($mdp){

	return password_hash($mdp, PASSWORD_BCRYPT);
}

function VerifyMDP($mdp, $hash){

	return password_verify($mdp, $hash);
}

function select_plugin(){
	global $_SESSION;
	
	$root_dir = 'DOCS';
	//liste des fichiers (plugins) actifs
	if(!is_array($_SESSION['last_page'])){$_SESSION['last_page'] = array();} //On definit la session en tableau

	$list_plugin = glob('./'.$root_dir.'/*.on.*'); //on liste tout les modules et page actif
	$nb_plugin = count($list_plugin)-1; // On compte le nombre total de modules et pages

	foreach($list_plugin as $key => $name){
		//Si on à passer tout les modules on vide la session pour recommencer
		if(in_array($nb_plugin, $_SESSION['last_page'])){
			$_SESSION['last_page'] = array();
		}
		if(!in_array($key, $_SESSION['last_page'])){// On met a jour le tableau et on assigne le nouveau module à afficher
			$_SESSION['last_page'][] = $key;
			$plugin_selected = $name;
			break;
		}
	}
	$out = array('p_infos' => explode('.',$plugin_selected), 'p_selected' => $plugin_selected);
	// Recupere les infos du module a afficher
	return $out;
}

function select_scrolling(){
	global $_SESSION;
	
	$root_dir = 'DOCS/scrolling';
	//liste des fichiers (plugins) actifs
	if(!is_array($_SESSION['last_slider'])){$_SESSION['last_slider'] = array();} //On definit la session en tableau

	$list_slider = glob('./'.$root_dir.'/Scrolling_*.on.*.html'); //on liste tout les slider actif
	$nb_slider = count($list_slider)-1; // On compte le nombre total de slider

	foreach($list_slider as $key => $name){
		//Si on à passer tout les slider on vide la session pour recommencer
		if(in_array($nb_slider, $_SESSION['last_slider'])){
			$_SESSION['last_slider'] = array();
		}
		if(!in_array($key, $_SESSION['last_slider'])){// On met a jour le tableau et on assigne le nouveau module à afficher
			$_SESSION['last_slider'][] = $key;
			$slider_selected = $name;
			break;
		}
	}
	$out = array('s_infos' => explode('.',$slider_selected), 's_selected' => $slider_selected);
	// Recupere les infos du module a afficher
	return $out;
}

function human_filesize($file, $decimals = 1) {
	$bytes = filesize($file);
	$sz = 'BKMGTP';
	$factor = floor((strlen($bytes) - 1) / 3);
	return sprintf("%.{$decimals}f", $bytes / pow(1024, $factor)) . @$sz[$factor];
}
?>